@@ -15,7 +15,12 @@ sensor = LC709203F(i2c)
 
 print("IC version:", hex(sensor.ic_version))
 while True:
-    print(
-        "Battery: %0.3f Volts / %0.1f %%" % (sensor.cell_voltage, sensor.cell_percent)
-    )
+    try:
+        print(
+            "Battery: %0.3f Volts / %0.1f %%"
+            % (sensor.cell_voltage, sensor.cell_percent)
+        )
+    except OSError:
+        print("retry reads")
+
     time.sleep(1)
